@@ -22,7 +22,7 @@ class CrudSchema(BaseSchema):
     TRIM_NULL_VALUES = False  # TODO
     PAGE_SIZE = 0
 
-    def __init__(self, filters, q_filters, initkwargs=None):
+    def __init__(self, filters, q_filters=None, initkwargs=None):
         # self.url_path = self.URL_PATH
         self.path = self.PATH
         self.model_class = self.MODEL_CLASS
